Mergers Module
==============

.. automodule:: moosefs.merging_strategies.base_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.borda_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.union_of_intersections_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.l2_norm_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.arithmetic_mean_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.consensus_merger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.merging_strategies.frequency_bootstrap_merger
   :members:
   :undoc-members:
   :show-inheritance:
